documentationtools.Documenter
=============================

.. abjad-lineage:: abjad.tools.documentationtools.Documenter.Documenter

.. autoclass:: abjad.tools.documentationtools.Documenter.Documenter

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.documentationtools.Documenter.Documenter.module_name
      ~abjad.tools.documentationtools.Documenter.Documenter.object_
      ~abjad.tools.documentationtools.Documenter.Documenter.prefix
      ~abjad.tools.documentationtools.Documenter.Documenter.write
      ~abjad.tools.documentationtools.Documenter.Documenter.__eq__
      ~abjad.tools.documentationtools.Documenter.Documenter.__makenew__
      ~abjad.tools.documentationtools.Documenter.Documenter.__ne__
      ~abjad.tools.documentationtools.Documenter.Documenter.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.Documenter.Documenter.module_name
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.Documenter.Documenter.object_
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.Documenter.Documenter.prefix
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.documentationtools.Documenter.Documenter.write
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.documentationtools.Documenter.Documenter.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.Documenter.Documenter.__makenew__
   :noindex:

.. automethod:: abjad.tools.documentationtools.Documenter.Documenter.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.Documenter.Documenter.__repr__
   :noindex:
